@@ -1602,10 +1602,12 @@ class API(base_api.NetworkAPI):
 
     def _nw_info_build_network(self, port, networks, subnets):
         network_name = None
+        network_mtu = None
         for net in networks:
             if port['network_id'] == net['id']:
                 network_name = net['name']
                 tenant_id = net['tenant_id']
+                network_mtu = net.get('mtu')
                 break
         else:
             tenant_id = port['tenant_id']
@@ -1648,7 +1650,8 @@ class API(base_api.NetworkAPI):
             bridge=bridge,
             injected=CONF.flat_injected,
             label=network_name,
-            tenant_id=tenant_id
+            tenant_id=tenant_id,
+            mtu=network_mtu
             )
         network['subnets'] = subnets
         port_profile = port.get('binding:profile')
@@ -1719,11 +1722,6 @@ class API(base_api.NetworkAPI):
             current_neutron_port_map[current_neutron_port['id']] = (
                 current_neutron_port)
 
-        # In that case we should repopulate ports from the state of
-        # Neutron.
-        if not port_ids:
-            port_ids = current_neutron_port_map.keys()
-
         for port_id in port_ids:
             current_neutron_port = current_neutron_port_map.get(port_id)
             if current_neutron_port:
