@@ -14,11 +14,13 @@
 import mock
 from oslo_log import log as logging
 
+from nova.compute import task_states
 from nova import exception
 from nova import objects
 from nova import test
 from nova import utils
 from nova.virt.libvirt.storage import rbd_utils
+from nova.virt.libvirt import utils as libvirt_utils
 
 
 LOG = logging.getLogger(__name__)
@@ -79,6 +81,7 @@ class RbdTestCase(test.NoDBTestCase):
         self.driver = rbd_utils.RBDDriver(self.rbd_pool, None, None)
 
         self.volume_name = u'volume-00000001'
+        self.snap_name = u'test-snap'
 
     def tearDown(self):
         super(RbdTestCase, self).tearDown()
@@ -96,7 +99,7 @@ class RbdTestCase(test.NoDBTestCase):
                      'rbd://fsid/pool/image/',
                      'rbd://fsid/pool/image/snap/',
                      'rbd://///', ]
-        image_meta = objects.ImageMeta.from_dict({'disk_format': 'raw'})
+        image_meta = {'disk_format': 'raw'}
 
         for loc in locations:
             self.assertRaises(exception.ImageUnacceptable,
@@ -110,7 +113,7 @@ class RbdTestCase(test.NoDBTestCase):
     def test_cloneable(self, mock_rados, mock_rbd, mock_get_fsid):
         mock_get_fsid.return_value = 'abc'
         location = {'url': 'rbd://abc/pool/image/snap'}
-        image_meta = objects.ImageMeta.from_dict({'disk_format': 'raw'})
+        image_meta = {'disk_format': 'raw'}
         self.assertTrue(self.driver.is_cloneable(location, image_meta))
         self.assertTrue(mock_get_fsid.called)
 
@@ -118,7 +121,7 @@ class RbdTestCase(test.NoDBTestCase):
     def test_uncloneable_different_fsid(self, mock_get_fsid):
         mock_get_fsid.return_value = 'abc'
         location = {'url': 'rbd://def/pool/image/snap'}
-        image_meta = objects.ImageMeta.from_dict({'disk_format': 'raw'})
+        image_meta = {'disk_format': 'raw'}
         self.assertFalse(
             self.driver.is_cloneable(location, image_meta))
         self.assertTrue(mock_get_fsid.called)
@@ -133,7 +136,7 @@ class RbdTestCase(test.NoDBTestCase):
         location = {'url': 'rbd://abc/pool/image/snap'}
 
         mock_proxy.side_effect = mock_rbd.Error
-        image_meta = objects.ImageMeta.from_dict({'disk_format': 'raw'})
+        image_meta = {'disk_format': 'raw'}
 
         self.assertFalse(
             self.driver.is_cloneable(location, image_meta))
@@ -147,11 +150,20 @@ class RbdTestCase(test.NoDBTestCase):
         location = {'url': 'rbd://abc/pool/image/snap'}
         formats = ['qcow2', 'vmdk', 'vdi']
         for f in formats:
-            image_meta = objects.ImageMeta.from_dict({'disk_format': f})
+            image_meta = {'disk_format': f}
             self.assertFalse(
                 self.driver.is_cloneable(location, image_meta))
         self.assertTrue(mock_get_fsid.called)
 
+    @mock.patch.object(rbd_utils.RBDDriver, '_get_fsid')
+    def test_uncloneable_missing_format(self, mock_get_fsid):
+        mock_get_fsid.return_value = 'abc'
+        location = {'url': 'rbd://abc/pool/image/snap'}
+        image_meta = {}
+        self.assertFalse(
+            self.driver.is_cloneable(location, image_meta))
+        self.assertTrue(mock_get_fsid.called)
+
     @mock.patch.object(utils, 'execute')
     def test_get_mon_addrs(self, mock_execute):
         mock_execute.return_value = (CEPH_MON_DUMP, '')
@@ -291,7 +303,7 @@ class RbdTestCase(test.NoDBTestCase):
     @mock.patch.object(rbd_utils, 'rados')
     @mock.patch.object(rbd_utils, 'RADOSClient')
     def test_cleanup_volumes(self, mock_client, mock_rados, mock_rbd):
-        instance = objects.Instance(id=1, uuid='12345')
+        instance = objects.Instance(id=1, uuid='12345', task_state=None)
 
         rbd = mock_rbd.RBD.return_value
         rbd.list.return_value = ['12345_test', '111_test']
@@ -307,7 +319,7 @@ class RbdTestCase(test.NoDBTestCase):
     @mock.patch.object(rbd_utils, 'RADOSClient')
     def _test_cleanup_exception(self, exception_name,
                                 mock_client, mock_rados, mock_rbd):
-        instance = objects.Instance(id=1, uuid='12345')
+        instance = objects.Instance(id=1, uuid='12345', task_state=None)
 
         setattr(mock_rbd, exception_name, test.TestingException)
         rbd = mock_rbd.RBD.return_value
@@ -331,6 +343,51 @@ class RbdTestCase(test.NoDBTestCase):
         self.assertRaises(test.TestingException,
                           self._test_cleanup_exception, 'DoesNotExist')
 
+    @mock.patch.object(rbd_utils, 'rbd')
+    @mock.patch.object(rbd_utils, 'rados')
+    @mock.patch.object(rbd_utils, 'RADOSClient')
+    @mock.patch.object(rbd_utils, 'RBDVolumeProxy')
+    def test_cleanup_volumes_pending_resize(self, mock_proxy, mock_client,
+                                            mock_rados, mock_rbd):
+        instance = objects.Instance(id=1, uuid='12345', task_state=None)
+
+        setattr(mock_rbd, 'ImageHasSnapshots', test.TestingException)
+        rbd = mock_rbd.RBD.return_value
+        rbd.remove.side_effect = [test.TestingException, None]
+        rbd.list.return_value = ['12345_test', '111_test']
+        proxy = mock_proxy.return_value
+        proxy.__enter__.return_value = proxy
+        proxy.list_snaps.return_value = [
+            {'name': libvirt_utils.RESIZE_SNAPSHOT_NAME}]
+        client = mock_client.return_value
+        self.driver.cleanup_volumes(instance)
+
+        remove_call = mock.call(client.ioctx, '12345_test')
+        rbd.remove.assert_has_calls([remove_call, remove_call])
+        proxy.remove_snap.assert_called_once_with(
+                libvirt_utils.RESIZE_SNAPSHOT_NAME)
+        client.__enter__.assert_called_once_with()
+        client.__exit__.assert_called_once_with(None, None, None)
+
+    @mock.patch.object(rbd_utils, 'rbd')
+    @mock.patch.object(rbd_utils, 'rados')
+    @mock.patch.object(rbd_utils, 'RADOSClient')
+    def test_cleanup_volumes_reverting_resize(self, mock_client, mock_rados,
+                                       mock_rbd):
+        instance = objects.Instance(id=1, uuid='12345',
+                                    task_state=task_states.RESIZE_REVERTING)
+
+        rbd = mock_rbd.RBD.return_value
+        rbd.list.return_value = ['12345_test', '111_test',
+                                 '12345_test_disk.local']
+
+        client = mock_client.return_value
+        self.driver.cleanup_volumes(instance)
+        rbd.remove.assert_called_once_with(client.ioctx,
+                                           '12345_test_disk.local')
+        client.__enter__.assert_called_once_with()
+        client.__exit__.assert_called_once_with(None, None, None)
+
     @mock.patch.object(rbd_utils, 'rbd')
     @mock.patch.object(rbd_utils, 'rados')
     @mock.patch.object(rbd_utils, 'RADOSClient')
@@ -345,3 +402,33 @@ class RbdTestCase(test.NoDBTestCase):
         # Make sure that we entered and exited the RADOSClient
         client.__enter__.assert_called_once_with()
         client.__exit__.assert_called_once_with(None, None, None)
+
+    @mock.patch.object(rbd_utils, 'RBDVolumeProxy')
+    def test_create_snap(self, mock_proxy):
+        proxy = mock_proxy.return_value
+        proxy.__enter__.return_value = proxy
+        self.driver.create_snap(self.volume_name, self.snap_name)
+        proxy.create_snap.assert_called_once_with(self.snap_name)
+
+    @mock.patch.object(rbd_utils, 'RBDVolumeProxy')
+    def test_remove_snap(self, mock_proxy):
+        proxy = mock_proxy.return_value
+        proxy.__enter__.return_value = proxy
+        self.driver.remove_snap(self.volume_name, self.snap_name)
+        self.assertFalse(proxy.remove_snap.called)
+
+        proxy.list_snaps.return_value = [{'name': self.snap_name}, ]
+        self.driver.remove_snap(self.volume_name, self.snap_name)
+        proxy.remove_snap.assert_called_once_with(self.snap_name)
+
+    @mock.patch.object(rbd_utils, 'RBDVolumeProxy')
+    def test_rollback_to_snap(self, mock_proxy):
+        proxy = mock_proxy.return_value
+        proxy.__enter__.return_value = proxy
+        self.assertRaises(exception.SnapshotNotFound,
+                          self.driver.rollback_to_snap,
+                          self.volume_name, self.snap_name)
+
+        proxy.list_snaps.return_value = [{'name': self.snap_name}, ]
+        self.driver.rollback_to_snap(self.volume_name, self.snap_name)
+        proxy.rollback_to_snap.assert_called_once_with(self.snap_name)
