@@ -257,7 +257,8 @@ def get_disk_bus_for_device_type(instance,
     elif virt_type in ("qemu", "kvm"):
         if device_type == "cdrom":
             guestarch = libvirt_utils.get_arch(image_meta)
-            if guestarch in (arch.PPC, arch.PPC64, arch.S390, arch.S390X):
+            if guestarch in (arch.PPC, arch.PPC64, arch.PPCLE, arch.PPC64LE,
+                arch.S390, arch.S390X):
                 return "scsi"
             else:
                 return "ide"
