@@ -355,7 +355,8 @@ def get_vm_resize_spec(client_factory, vcpus, memory_mb, extra_specs,
 
 
 def create_controller_spec(client_factory, key,
-                           adapter_type=constants.DEFAULT_ADAPTER_TYPE):
+                           adapter_type=constants.DEFAULT_ADAPTER_TYPE,
+                           bus_number=0):
     """Builds a Config Spec for the LSI or Bus Logic Controller's addition
     which acts as the controller for the virtual hard disk to be attached
     to the VM.
@@ -377,7 +378,7 @@ def create_controller_spec(client_factory, key,
         virtual_controller = client_factory.create(
                                 'ns0:VirtualLsiLogicController')
     virtual_controller.key = key
-    virtual_controller.busNumber = 0
+    virtual_controller.busNumber = bus_number
     virtual_controller.sharedBus = "noSharing"
     virtual_device_config.device = virtual_controller
     return virtual_device_config
@@ -713,6 +714,19 @@ def _find_allocated_slots(devices):
     return taken
 
 
+def _get_bus_number_for_scsi_controller(devices):
+    """Return usable bus number when create new SCSI controller."""
+    # Every SCSI controller will take a unique bus number
+    taken = [dev.busNumber for dev in devices if _is_scsi_controller(dev)]
+    # The max bus number for SCSI controllers is 3
+    for i in range(constants.SCSI_MAX_CONTROLLER_NUMBER):
+        if i not in taken:
+            return i
+    msg = _('Only %d SCSI controllers are allowed to be '
+            'created on this instance.') % constants.SCSI_MAX_CONTROLLER_NUMBER
+    raise vexc.VMwareDriverException(msg)
+
+
 def allocate_controller_key_and_unit_number(client_factory, devices,
                                             adapter_type):
     """This function inspects the current set of hardware devices and returns
@@ -728,10 +742,7 @@ def allocate_controller_key_and_unit_number(client_factory, devices,
     if adapter_type == constants.ADAPTER_TYPE_IDE:
         ide_keys = [dev.key for dev in devices if _is_ide_controller(dev)]
         ret = _find_controller_slot(ide_keys, taken, 2)
-    elif adapter_type in [constants.DEFAULT_ADAPTER_TYPE,
-                          constants.ADAPTER_TYPE_LSILOGICSAS,
-                          constants.ADAPTER_TYPE_BUSLOGIC,
-                          constants.ADAPTER_TYPE_PARAVIRTUAL]:
+    elif adapter_type in constants.SCSI_ADAPTER_TYPES:
         scsi_keys = [dev.key for dev in devices if _is_scsi_controller(dev)]
         ret = _find_controller_slot(scsi_keys, taken, 16)
     if ret:
@@ -739,8 +750,14 @@ def allocate_controller_key_and_unit_number(client_factory, devices,
 
     # create new controller with the specified type and return its spec
     controller_key = -101
+
+    # Get free bus number for new SCSI controller.
+    bus_number = 0
+    if adapter_type in constants.SCSI_ADAPTER_TYPES:
+        bus_number = _get_bus_number_for_scsi_controller(devices)
+
     controller_spec = create_controller_spec(client_factory, controller_key,
-                                             adapter_type)
+                                             adapter_type, bus_number)
     return controller_key, 0, controller_spec
 
 
